@@ -5,11 +5,11 @@
 namespace Icinga\Module\Icingadb\Model;
 
 use DateTime;
-use Icinga\Module\Icingadb\Model\Behavior\BoolCast;
+use ipl\Orm\Behavior\BoolCast;
 use ipl\Orm\Behavior\Binary;
 use ipl\Orm\Behavior\MillisecondTimestamp;
 use ipl\Orm\Behaviors;
-use Icinga\Module\Icingadb\Common\Model;
+use ipl\Orm\Model;
 use ipl\Orm\Relations;
 
 /**
